import { Jalali } from 'jalali-ts';
import * as i0 from '@angular/core';
import { Directive, HostListener, Pipe, EventEmitter, Component, ContentChild, Input, Output, NgModule } from '@angular/core';
import { FormControlDirective, FormControlName } from '@angular/forms';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

const defaultTheme = {
    border: '#CCCCCC',
    timeBorder: '#CCCCCC',
    background: '#FFFFFF',
    text: '#333333',
    hoverBackground: '#007BE6',
    hoverText: '#FFFFFF',
    disabledBackground: '#F1F1F1',
    disabledText: '#CCCCCC',
    selectedBackground: '#005299',
    selectedText: '#FFFFFF',
    todayBackground: '#333333',
    todayText: '#FFFFFF',
    otherMonthBackground: 'rgba(0, 0, 0, 0)',
    otherMonthText: '#CCCCCC'
};

const weekDays = ['ش', 'ی', 'د', 'س', 'چ', 'پ', 'ج'];
const months = [
    'فروردین',
    'اردیبهشت',
    'خرداد',
    'تیر',
    'مرداد',
    'شهریور',
    'مهر',
    'آبان',
    'آذر',
    'دی',
    'بهمن',
    'اسفند',
];

class ThemeHoverDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    onMouseOver() {
        this.elementRef.nativeElement?.classList?.add('hover');
    }
    onMouseOut() {
        this.elementRef.nativeElement?.classList?.remove('hover');
    }
}
ThemeHoverDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: ThemeHoverDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
ThemeHoverDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.8", type: ThemeHoverDirective, selector: "[themeHover]", host: { listeners: { "mouseover": "onMouseOver()", "mouseout": "onMouseOut()" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: ThemeHoverDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[themeHover]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { onMouseOver: [{
                type: HostListener,
                args: ['mouseover']
            }], onMouseOut: [{
                type: HostListener,
                args: ['mouseout']
            }] } });

class MonthPipe {
    transform(index) {
        return months[index];
    }
}
MonthPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: MonthPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonthPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: MonthPipe, name: "month" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: MonthPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'month'
                }]
        }] });

class NgPersianDatepickerComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.dateValue = 0;
        this.preventClose = false;
        this.uiYearView = true;
        this.uiMonthView = true;
        this.wasInsideClick = false;
        this.viewDateTitle = '';
        this.viewModes = [];
        this.viewModeIndex = 0;
        this.weekDays = weekDays;
        this.years = [];
        this.months = [];
        this.days = [];
        this.hour = 0;
        this.minute = 0;
        this.second = 0;
        this.dateInitValue = true;
        this.dateIsGregorian = false;
        this.dateFormat = 'YYYY/MM/DD';
        this.dateGregorianFormat = 'YYYY-MM-DD';
        this.dateMin = null;
        this.dateMax = null;
        // time
        this.timeEnable = false;
        this.timeShowSecond = false;
        this.timeMeridian = false;
        // ui
        this.uiTheme = defaultTheme;
        this.uiIsVisible = false;
        this.uiHideOnOutsideClick = true;
        this.uiHideAfterSelectDate = true;
        this.uiInitViewMode = 'day';
        this.uiTodayBtnEnable = true;
        /** @Output */
        // date
        this.dateOnInit = new EventEmitter();
        this.dateOnSelect = new EventEmitter();
        // ui
        this.uiIsVisibleChange = new EventEmitter();
        this.setToday();
    }
    /** @ReactiveForm */
    set _formControlDirective(value) {
        this.setFormControl(value?.control);
    }
    set _formControlName(value) {
        this.setFormControl(value?.control);
    }
    set _dateFormat(value) {
        this.dateFormat = value.replace(new RegExp('j', 'g'), '');
    }
    set _dateMin(value) {
        this.dateMin = value;
        if (this.days.length)
            this.setViewDate();
    }
    set _dateMax(value) {
        this.dateMax = value;
        if (this.days.length)
            this.setViewDate();
    }
    set _timeEnable(value) {
        this.timeEnable = value;
        this.setTime();
        this.scrollIntoActiveTime();
    }
    set _timeShowSecond(value) {
        this.timeShowSecond = value;
        this.scrollIntoActiveTime();
    }
    set _timeMeridian(value) {
        this.timeMeridian = value;
        this.scrollIntoActiveTime();
    }
    set _uiTheme(value) {
        this.uiTheme = { ...defaultTheme, ...value };
    }
    set _uiYearView(value) {
        this.uiYearView = value;
        this.checkViewModes();
        this.setViewDateTitle();
    }
    set _uiMonthView(value) {
        this.uiMonthView = value;
        this.checkViewModes();
        this.setViewDateTitle();
    }
    ngOnInit() {
        this.setViewModes();
        this.setInitViewMode();
        this.setShowOnInputFocus();
        if (this.inputDateValue)
            this.setFormControl(this.inputDateValue);
    }
    ngOnDestroy() {
        this.formControlValueChanges?.unsubscribe();
        if (this.input) {
            this.input.removeEventListener('focus', this.inputEventFocusListener);
        }
    }
    setFormControl(value) {
        if (!value)
            return;
        this.formControl = value;
        if (!this.dateValue) {
            this.setDateInitValue(this.formControl?.value);
            this.setSelectedDate(this.formControl?.value);
            this.setViewDate();
            this.setTime();
            this.setFormControlValue();
        }
        this.formControlValueChanges?.unsubscribe();
        this.formControlValueChanges = this.formControl
            ?.valueChanges
            ?.subscribe({
            next: (value) => {
                let valueOf = 0;
                if (value) {
                    try {
                        valueOf = this.valueOfDate(value);
                    }
                    catch (e) {
                        return;
                    }
                }
                if (!value || valueOf === this.dateValue)
                    return;
                const date = Jalali.timestamp(valueOf);
                if (!this.isDateInRange(date.valueOf(), false, false)) {
                    return;
                }
                this.setTime(date);
                this.changeSelectedDate(date, false);
                this.scrollIntoActiveTime();
            }
        });
    }
    setToday() {
        const today = Jalali.now();
        if (!this.timeEnable)
            today.startOf('day');
        this.today = today;
    }
    setViewModes() {
        this.viewModes = ['day'];
        if (this.uiMonthView) {
            this.viewModes.push('month');
        }
        if (this.uiYearView) {
            this.viewModes.push('year');
        }
        if (this.viewModes.length <= this.viewModeIndex) {
            this.viewModeIndex = 0;
        }
    }
    setInitViewMode() {
        const index = this.viewModes.indexOf(this.uiInitViewMode);
        if (index !== -1)
            this.viewModeIndex = index;
    }
    checkViewModes() {
        let viewModesCount = 1;
        if (this.uiYearView) {
            viewModesCount++;
        }
        if (this.uiMonthView) {
            viewModesCount++;
        }
        if (viewModesCount !== this.viewModes.length) {
            this.setViewModes();
        }
    }
    setDateInitValue(dateValue) {
        if (dateValue || !this.dateInitValue) {
            return;
        }
        this.dateValue = this.today.valueOf();
        this.selectedDate = Jalali.timestamp(this.dateValue);
        this.dateOnInit.next({
            shamsi: String(this.selectedDate.format(this.dateFormat)),
            gregorian: String(this.selectedDate.gregorian(this.dateGregorianFormat)),
            timestamp: Number(this.selectedDate.valueOf())
        });
    }
    setSelectedDate(dateValue) {
        if (!dateValue) {
            return;
        }
        const date = Jalali.timestamp(this.valueOfDate(dateValue));
        if (!this.timeEnable)
            date.startOf('day');
        this.dateValue = date.valueOf();
        this.selectedDate = date;
    }
    setViewDate() {
        if (!this.dateValue) {
            this.viewDate = this.dateMax ? Jalali.timestamp(this.dateMax).endOf('year') : this.today.clone();
        }
        else {
            this.viewDate = this.dateMax && this.selectedDate.valueOf() > this.dateMax.valueOf() ?
                Jalali.timestamp(this.dateMax) : this.selectedDate.clone();
        }
        if (!this.timeEnable)
            this.viewDate.startOf('day');
        this.onChangeViewDate();
    }
    onChangeViewDate() {
        this.viewDate.startOf('month');
        this.setYears();
        this.setMonths();
        this.setDays();
        this.setViewDateTitle();
    }
    setYears() {
        this.years = [];
        const years = this.viewDate.clone();
        years.startOf('year');
        years.add(-6, 'year');
        for (let i = 0; i < 12; i++) {
            const year = [years.valueOf(), years.getFullYear()];
            this.years.push({
                timestamp: year[0],
                value: year[1],
                isYearOfTodayDate: this.isYearOfTodayDate(year),
                isYearOfSelectedDate: this.isYearOfSelectedDate(year),
                isYearDisabled: this.isYearDisabled(year)
            });
            years.add(1, 'year');
        }
    }
    setMonths() {
        this.months = [];
        const months = this.viewDate.clone();
        months.startOf('year');
        for (let i = 0; i < 12; i++) {
            const month = [months.valueOf(), months.getFullYear(), months.getMonth()];
            this.months.push({
                timestamp: month[0],
                year: month[1],
                indexValue: month[2],
                isMonthOfTodayDate: this.isMonthOfToday(month),
                isMonthOfSelectedDate: this.isMonthOfSelectedDate(month),
                isMonthDisabled: this.isMonthDisabled(month)
            });
            months.add(1, 'month');
        }
    }
    setDays() {
        this.days = [];
        const prevMonthDetails = [];
        const currentMonthDetails = [];
        const nextMonthDetails = [];
        const prevMonth = Jalali.timestamp(this.viewDate.valueOf());
        const currentMonth = Jalali.timestamp(this.viewDate.valueOf());
        const nextMonth = Jalali.timestamp(this.viewDate.valueOf());
        prevMonth.add(-1, 'month');
        nextMonth.add(1, 'month');
        const currentMonthDays = currentMonth.monthLength();
        const prevMonthDays = prevMonth.monthLength();
        const nextMonthDays = nextMonth.monthLength();
        for (let i = 0; i < prevMonthDays; i++) {
            prevMonthDetails.push([prevMonth.valueOf(), prevMonth.getFullYear(), prevMonth.getMonth(), prevMonth.getDate()]);
            prevMonth.add(1, 'day');
        }
        for (let i = 0; i < currentMonthDays; i++) {
            currentMonthDetails.push([currentMonth.valueOf(), currentMonth.getFullYear(), currentMonth.getMonth(), currentMonth.getDate()]);
            currentMonth.add(1, 'day');
        }
        for (let i = 0; i < nextMonthDays; i++) {
            nextMonthDetails.push([nextMonth.valueOf(), nextMonth.getFullYear(), nextMonth.getMonth(), nextMonth.getDate()]);
            nextMonth.add(1, 'day');
        }
        for (let row = 0; row < 6; row++) {
            const rowValue = [];
            for (let col = 0; col < 7; col++) {
                const fromPrevMonth = (this.viewDate.date.getDay() === 6) ? 0 : (this.viewDate.date.getDay() + 1);
                let index = ((row * 7) + col) - fromPrevMonth;
                let day = [];
                if (index < 0) {
                    index = prevMonthDetails.length - (fromPrevMonth - col);
                    day = prevMonthDetails[index];
                }
                else if (index >= currentMonthDetails.length) {
                    index = index - currentMonthDetails.length;
                    day = nextMonthDetails[index];
                }
                else {
                    day = currentMonthDetails[index];
                }
                rowValue.push({
                    timestamp: day[0],
                    year: day[1],
                    monthIndex: day[2],
                    value: day[3],
                    isDayInCurrentMonth: this.isDayInCurrentMonth(day),
                    isDayOfTodayDate: this.isDayOfTodayDate(day),
                    isDayOfSelectedDate: this.isDayOfSelectedDate(day),
                    isDayDisabled: this.isDayDisabled(day)
                });
            }
            this.days.push(rowValue);
        }
    }
    setViewDateTitle() {
        const year = this.viewDate ? this.viewDate.getFullYear() : 0;
        if (!year) {
            return;
        }
        switch (this.viewModes[this.viewModeIndex]) {
            case 'day':
                this.viewDateTitle = months[this.viewDate.getMonth()] + ' ' + year.toString();
                break;
            case 'month':
                this.viewDateTitle = year.toString();
                break;
            case 'year':
                this.viewDateTitle = (year - 6).toString() + '-' + (year + 5).toString();
                break;
        }
    }
    setTime(date = null) {
        if (date) {
            this.hour = date.getHours();
            this.minute = date.getMinutes();
            this.second = date.getSeconds();
        }
        else if (this.selectedDate) {
            this.hour = this.selectedDate.getHours();
            this.minute = this.selectedDate.getMinutes();
            this.second = this.selectedDate.getSeconds();
        }
        else {
            this.hour = this.today.getHours();
            this.minute = this.today.getMinutes();
            this.second = this.today.getSeconds();
        }
    }
    setFormControlValue() {
        if (!this.formControl) {
            return;
        }
        if (this.dateValue) {
            this.formControl?.setValue(Jalali.timestamp(this.dateValue).format(this.dateFormat));
        }
    }
    setShowOnInputFocus() {
        const input = this.elementRef.nativeElement?.querySelector('input');
        if (!input) {
            return;
        }
        this.inputEventFocusListener = () => {
            if (!this.uiIsVisible) {
                this.setUiIsVisible(true);
            }
        };
        this.input = input;
        this.input.addEventListener('focus', this.inputEventFocusListener);
    }
    skipViewDate(skip, type) {
        if (type === 1) {
            this.viewDate.add(skip, 'year');
        }
        else if (type === 2) {
            this.viewDate.add(skip, 'month');
        }
    }
    navigate(forward) {
        let skip = 1;
        if (!forward) {
            skip = skip * -1;
        }
        switch (this.viewModes[this.viewModeIndex]) {
            case 'day':
                this.skipViewDate(skip, 2);
                break;
            case 'month':
                this.skipViewDate(skip, 1);
                break;
            case 'year':
                this.skipViewDate((skip * 12), 1);
                break;
        }
        this.onChangeViewDate();
    }
    nextViewMode() {
        if (this.viewModes.length === 1) {
            return;
        }
        if (this.viewModes.length <= (this.viewModeIndex + 1)) {
            this.viewModeIndex = 0;
        }
        else {
            this.viewModeIndex++;
        }
        this.setViewDateTitle();
    }
    selectToday() {
        this.setToday();
        this.preventClose = true;
        this.changeSelectedDate(this.today);
    }
    yearClick(year) {
        if (year.isYearDisabled) {
            return;
        }
        this.viewDate = Jalali.timestamp(year.timestamp);
        let viewModeIndex = this.viewModes.indexOf('month');
        if (viewModeIndex === -1) {
            viewModeIndex = this.viewModes.indexOf('day');
        }
        this.viewModeIndex = viewModeIndex;
        this.onChangeViewDate();
    }
    monthClick(month) {
        if (month.isMonthDisabled) {
            return;
        }
        this.viewDate = Jalali.timestamp(month.timestamp);
        this.viewModeIndex = this.viewModes.indexOf('day');
        this.onChangeViewDate();
    }
    dayClick(day) {
        if (day.isDayDisabled) {
            return;
        }
        this.changeSelectedDate(Jalali.timestamp(day.timestamp));
    }
    isYearOfTodayDate(year) {
        return (this.today.getFullYear() === year[1]);
    }
    isYearOfSelectedDate(year) {
        if (!this.selectedDate) {
            return false;
        }
        return (year[1] === this.selectedDate.getFullYear());
    }
    isYearDisabled(month) {
        return !this.isDateInRange(month[0], true, false);
    }
    isMonthOfToday(month) {
        return (this.today.getFullYear() === month[1] &&
            this.today.getMonth() === month[2]);
    }
    isMonthOfSelectedDate(month) {
        if (!this.selectedDate) {
            return false;
        }
        return (month[1] === this.selectedDate.getFullYear() &&
            month[2] === this.selectedDate.getMonth());
    }
    isMonthDisabled(month) {
        return !this.isDateInRange(month[0], false, true);
    }
    isDayInCurrentMonth(day) {
        return (day[1] === this.viewDate.getFullYear() &&
            day[2] === this.viewDate.getMonth());
    }
    isDayOfTodayDate(day) {
        return (day[1] === this.today.getFullYear() &&
            day[2] === this.today.getMonth() &&
            day[3] === this.today.getDate());
    }
    isDayOfSelectedDate(day) {
        if (!this.selectedDate) {
            return false;
        }
        return (day[1] === this.selectedDate.getFullYear() &&
            day[2] === this.selectedDate.getMonth() &&
            day[3] === this.selectedDate.getDate());
    }
    isDayDisabled(day) {
        return !this.isDateInRange(day[0], false, false);
    }
    isDateInRange(date, isYear, isMonth) {
        const result = [];
        if (this.dateMin) {
            const min = Jalali.timestamp(this.dateMin);
            if (isYear) {
                min.startOf('year');
            }
            if (isMonth) {
                min.startOf('month');
            }
            result.push(min.valueOf() <= date);
        }
        if (this.dateMax) {
            const max = Jalali.timestamp(this.dateMax);
            if (isYear) {
                max.startOf('year');
            }
            if (isMonth) {
                max.startOf('month');
            }
            result.push(max.valueOf() >= date);
        }
        return !(result.indexOf(false) !== -1);
    }
    changeSelectedDate(date, setInputValue = true) {
        this.selectedDate = date.clone();
        this.onChangeSelectedDate(setInputValue);
    }
    onChangeSelectedDate(setInputValue) {
        if (this.timeEnable) {
            this.selectedDate.setHours(this.hour);
            this.selectedDate.setMinutes(this.minute);
            this.selectedDate.setSeconds(this.second);
            this.selectedDate.setMilliseconds(0);
        }
        else {
            this.setToday();
            this.selectedDate.setHours(this.today.getHours());
            this.selectedDate.setMinutes(this.today.getMinutes());
            this.selectedDate.setSeconds(this.today.getSeconds());
            this.selectedDate.setMilliseconds(this.today.getMilliseconds());
        }
        this.dateValue = this.selectedDate.valueOf();
        if (this.uiHideAfterSelectDate && !this.preventClose) {
            this.setUiIsVisible(false);
        }
        else {
            this.preventClose = false;
        }
        if (setInputValue) {
            this.setFormControlValue();
        }
        this.setViewDate();
        this.dateOnSelect.next({
            shamsi: String(this.selectedDate.format(this.dateFormat)),
            gregorian: String(this.selectedDate.gregorian(this.dateGregorianFormat)),
            timestamp: Number(this.selectedDate.valueOf())
        });
    }
    set12Hour(value) {
        let hour = value;
        const isAM = this.hour < 12;
        const isPM = this.hour >= 12;
        if (isAM && hour === 12) {
            hour = 0;
        }
        if (isPM && hour === 12) {
            hour = 12;
        }
        if (isPM && hour < 12) {
            hour = value + 12;
        }
        this.setHour(hour);
    }
    setHour(value) {
        if (value === this.hour) {
            return;
        }
        this.hour = value;
        this.onTimeChange();
    }
    setMinute(value) {
        if (value === this.minute) {
            return;
        }
        this.minute = value;
        this.onTimeChange();
    }
    setSecond(value) {
        if (value === this.second) {
            return;
        }
        this.second = value;
        this.onTimeChange();
    }
    toggleAmPm(current) {
        if ((current === 'AM' && this.hour < 12) || (current === 'PM' && this.hour >= 12)) {
            return;
        }
        if (this.hour < 12) {
            this.hour += 12;
        }
        else {
            this.hour -= 12;
        }
        this.onTimeChange();
    }
    onTimeChange() {
        this.preventClose = true;
        this.changeSelectedDate(this.selectedDate);
    }
    scrollIntoActiveTime() {
        if (!this.uiIsVisible || !this.timeEnable) {
            return;
        }
        setTimeout(() => {
            // Hour
            const activeHour = this.elementRef.nativeElement?.querySelector('.time-col.hour-col .dp-btn.selected');
            if (activeHour)
                activeHour.scrollIntoView({ block: 'center' });
            // Minute
            const activeMinute = this.elementRef.nativeElement?.querySelector('.time-col.minute-col .dp-btn.selected');
            if (activeMinute)
                activeMinute.scrollIntoView({ block: 'center' });
            // Second
            const activeSecond = this.elementRef.nativeElement?.querySelector('.time-col.second-col .dp-btn.selected');
            if (activeSecond)
                activeSecond.scrollIntoView({ block: 'center' });
        }, 10);
    }
    onInsideClick() {
        this.wasInsideClick = true;
    }
    onOutsideClick() {
        const wasInsideClick = Boolean(this.wasInsideClick);
        this.wasInsideClick = false;
        if (wasInsideClick || !this.uiHideOnOutsideClick) {
            return;
        }
        this.setUiIsVisible(false);
    }
    valueOfDate(date) {
        if (typeof date === 'string') {
            const gregorian = (this.dateIsGregorian && !this.dateValue);
            return Jalali.parse(date, gregorian).valueOf();
        }
        return date;
    }
    setUiIsVisible(value) {
        this.uiIsVisible = value;
        this.uiIsVisibleChange.next(value);
        this.scrollIntoActiveTime();
    }
}
NgPersianDatepickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
NgPersianDatepickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.8", type: NgPersianDatepickerComponent, selector: "ng-persian-datepicker", inputs: { inputDateValue: ["dateValue", "inputDateValue"], dateInitValue: "dateInitValue", dateIsGregorian: "dateIsGregorian", _dateFormat: ["dateFormat", "_dateFormat"], dateGregorianFormat: "dateGregorianFormat", _dateMin: ["dateMin", "_dateMin"], _dateMax: ["dateMax", "_dateMax"], _timeEnable: ["timeEnable", "_timeEnable"], _timeShowSecond: ["timeShowSecond", "_timeShowSecond"], _timeMeridian: ["timeMeridian", "_timeMeridian"], _uiTheme: ["uiTheme", "_uiTheme"], uiIsVisible: "uiIsVisible", uiHideOnOutsideClick: "uiHideOnOutsideClick", uiHideAfterSelectDate: "uiHideAfterSelectDate", _uiYearView: ["uiYearView", "_uiYearView"], _uiMonthView: ["uiMonthView", "_uiMonthView"], uiInitViewMode: "uiInitViewMode", uiTodayBtnEnable: "uiTodayBtnEnable" }, outputs: { dateOnInit: "dateOnInit", dateOnSelect: "dateOnSelect", uiIsVisibleChange: "uiIsVisibleChange" }, host: { listeners: { "click": "onInsideClick()", "document:click": "onOutsideClick()" } }, queries: [{ propertyName: "_formControlDirective", first: true, predicate: FormControlDirective, descendants: true }, { propertyName: "_formControlName", first: true, predicate: FormControlName, descendants: true }], ngImport: i0, template: "<div class=\"datepicker-content\">\n  <ng-content></ng-content>\n  <div class=\"datepicker-outer-container\"\n       [style.backgroundColor]=\"uiTheme.background\"\n       [style.color]=\"uiTheme.text\"\n       [style.borderColor]=\"uiTheme.border\"\n       [class.hide]=\"!uiIsVisible\">\n    <div class=\"datepicker-inner-container\">\n\n      <!-- Start: navigation -->\n      <div class=\"content-container navigation-container horizontal-padding\">\n        <div class=\"go-back dp-btn\"\n             [style.backgroundColor]=\"goBack.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             (click)=\"navigate(false)\" themeHover #goBack>\n          <svg xmlns=\"http://www.w3.org/2000/svg\"\n               viewBox=\"0 0 240.823 240.823\"\n               [style.fill]=\"goBack.classList.contains('hover') ? uiTheme.hoverText : uiTheme.text\">\n            <path d=\"M183.189,111.816L74.892,3.555c-4.752-4.74-12.451-4.74-17.215,0c-4.752,4.74-4.752,12.439,0,17.179\n                   l99.707,99.671l-99.695,99.671c-4.752,4.74-4.752,12.439,0,17.191c4.752,4.74,12.463,4.74,17.215,0l108.297-108.261\n                   C187.881,124.315,187.881,116.495,183.189,111.816z\"></path>\n          </svg>\n        </div>\n        <div class=\"switch-view dp-btn\"\n             [style.backgroundColor]=\"switchView.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             [style.color]=\"switchView.classList.contains('hover') ? uiTheme.hoverText : null\"\n             (click)=\"nextViewMode()\" themeHover #switchView>\n          <span>{{ viewDateTitle }}</span>\n        </div>\n        <div class=\"go-forward dp-btn\"\n             [style.backgroundColor]=\"goForward.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             (click)=\"navigate(true)\" themeHover #goForward>\n          <svg xmlns=\"http://www.w3.org/2000/svg\"\n               viewBox=\"0 0 240.823 240.823\"\n               [style.fill]=\"goForward.classList.contains('hover') ? uiTheme.hoverText : uiTheme.text\">\n            <path d=\"M57.633,129.007L165.93,237.268c4.752,4.74,12.451,4.74,17.215,0c4.752-4.74,4.752-12.439,0-17.179\n                   l-99.707-99.671l99.695-99.671c4.752-4.74,4.752-12.439,0-17.191c-4.752-4.74-12.463-4.74-17.215,0L57.621,111.816\n                   C52.942,116.507,52.942,124.327,57.633,129.007z\"></path>\n          </svg>\n        </div>\n      </div>\n      <!-- End: navigation -->\n\n      <!-- Start: year view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'year'\"\n           class=\"years-container horizontal-padding\">\n        <div class=\"content-container\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <div class=\"year-col three-col-per-row\"\n               (click)=\"yearClick(year)\"\n               *ngFor=\"let year of years\">\n            <div class=\"dp-btn\"\n                 [class.disabled]=\"year.isYearDisabled\"\n                 [class.selected]=\"year.isYearOfSelectedDate\"\n                 [class.today]=\"year.isYearOfTodayDate\"\n                 [style.backgroundColor]=\"\n                   (year.isYearDisabled) ?\n                     uiTheme.disabledBackground :\n                     (year.isYearOfSelectedDate) ?\n                       uiTheme.selectedBackground :\n                       (yearCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         (year.isYearOfTodayDate) ?\n                           uiTheme.todayBackground :\n                           null\n                 \"\n                 [style.color]=\"\n                   (year.isYearDisabled) ?\n                     uiTheme.disabledText :\n                     (year.isYearOfSelectedDate) ?\n                       uiTheme.selectedText :\n                       (yearCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         (year.isYearOfTodayDate) ?\n                           uiTheme.todayText :\n                           null\n                 \"\n                 themeHover #yearCol>\n              <span>{{ year.value }}</span>\n            </div>\n          </div>\n        </div>\n      </div>\n      <!-- End: year view mode -->\n\n      <!-- Start: month view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'month'\"\n           class=\"months-container horizontal-padding\">\n        <div class=\"content-container\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <div class=\"month-col three-col-per-row\"\n               (click)=\"monthClick(month)\"\n               *ngFor=\"let month of months\">\n            <div class=\"dp-btn\"\n                 [class.disabled]=\"month.isMonthDisabled\"\n                 [class.selected]=\"month.isMonthOfSelectedDate\"\n                 [class.today]=\"month.isMonthOfTodayDate\"\n                 [style.backgroundColor]=\"\n                   (month.isMonthDisabled) ?\n                     uiTheme.disabledBackground :\n                     (month.isMonthOfSelectedDate) ?\n                       uiTheme.selectedBackground :\n                       (monthCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         (month.isMonthOfTodayDate) ?\n                           uiTheme.todayBackground :\n                           null\n                 \"\n                 [style.color]=\"\n                   (month.isMonthDisabled) ?\n                     uiTheme.disabledText :\n                     (month.isMonthOfSelectedDate) ?\n                       uiTheme.selectedText :\n                       (monthCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         (month.isMonthOfTodayDate) ?\n                           uiTheme.todayText :\n                           null\n                 \"\n                 themeHover #monthCol>\n              <span>{{ month.indexValue | month }}</span>\n            </div>\n          </div>\n        </div>\n      </div>\n      <!-- End: month view mode -->\n\n      <!-- Start: day view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'day'\"\n           class=\"days-container horizontal-padding\">\n        <div class=\"content-container week-days\">\n          <div class=\"day-col\"\n               *ngFor=\"let weekDay of weekDays\">\n            <span>{{ weekDay }}</span>\n          </div>\n        </div>\n        <div class=\"content-container month-days\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <ng-container *ngFor=\"let row of days\">\n            <div class=\"day-col\"\n                 (click)=\"dayClick(day)\"\n                 *ngFor=\"let day of row\">\n              <div class=\"dp-btn\"\n                   [class.disabled]=\"day.isDayDisabled\"\n                   [class.selected]=\"day.isDayOfSelectedDate\"\n                   [class.today]=\"day.isDayOfTodayDate\"\n                   [class.other-month]=\"!day.isDayInCurrentMonth\"\n                   [style.backgroundColor]=\"\n                     (day.isDayDisabled) ?\n                       uiTheme.disabledBackground :\n                       (day.isDayOfSelectedDate) ?\n                         uiTheme.selectedBackground :\n                         (dayCol.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           (day.isDayOfTodayDate) ?\n                             uiTheme.todayBackground :\n                             (!day.isDayInCurrentMonth) ?\n                               uiTheme.otherMonthBackground :\n                               null\n                   \"\n                   [style.color]=\"\n                     (day.isDayDisabled) ?\n                       uiTheme.disabledText :\n                       (day.isDayOfSelectedDate) ?\n                         uiTheme.selectedText :\n                         (dayCol.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           (day.isDayOfTodayDate) ?\n                             uiTheme.todayText :\n                             (!day.isDayInCurrentMonth) ?\n                               uiTheme.otherMonthText :\n                               null\n                   \"\n                   themeHover #dayCol>\n                <span>{{ day.value }}</span>\n              </div>\n            </div>\n          </ng-container>\n        </div>\n      </div>\n      <!-- End: day view mode -->\n\n      <!-- Start: time picker -->\n      <ng-container *ngIf=\"timeEnable\">\n        <div class=\"time-container horizontal-padding content-container\"\n             [style.borderTopColor]=\"uiTheme.timeBorder\"\n             [style.borderBottomColor]=\"uiTheme.timeBorder\">\n          <div class=\"time-col hour-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <ng-container *ngIf=\"!timeMeridian\">\n              <div class=\"item\"\n                   *ngFor=\"let _ of [].constructor(24); let i = index\">\n                <div class=\"dp-btn\"\n                     (click)=\"setHour(i)\"\n                     [class.selected]=\"hour === i\"\n                     [style.backgroundColor]=\"\n                       (hour === i) ?\n                         uiTheme.selectedBackground :\n                         (hourCol.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           null\n                     \"\n                     [style.color]=\"\n                       (hour === i) ?\n                         uiTheme.selectedText :\n                         (hourCol.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           null\n                     \" themeHover #hourCol>\n                  <span>{{ i | number: '2.0' }}</span>\n                </div>\n              </div>\n            </ng-container>\n            <ng-container *ngIf=\"timeMeridian\">\n              <div class=\"item\"\n                   *ngFor=\"let _ of [].constructor(12); let i = index\">\n                <div class=\"dp-btn\"\n                     (click)=\"set12Hour(i + 1)\"\n                     [class.selected]=\"\n                       (hour === 0 && (i + 1) === 12) ||\n                       (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                       (hour > 12 && hour === ((i + 1) + 12))\n                     \"\n                     [style.backgroundColor]=\"\n                       (\n                         (hour === 0 && (i + 1) === 12) ||\n                         (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                         (hour > 12 && hour === ((i + 1) + 12))\n                       ) ?\n                         uiTheme.selectedBackground :\n                         (hour12Col.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           null\n                     \"\n                     [style.color]=\"\n                       (\n                         (hour === 0 && (i + 1) === 12) ||\n                         (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                         (hour > 12 && hour === ((i + 1) + 12))\n                       ) ?\n                         uiTheme.selectedText :\n                         (hour12Col.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           null\n                     \" themeHover #hour12Col>\n                  <span>{{ (i + 1) | number: '2.0' }}</span>\n                </div>\n              </div>\n            </ng-container>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div class=\"time-col minute-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <div class=\"item\"\n                 *ngFor=\"let _ of [].constructor(60); let i = index\">\n              <div class=\"dp-btn\"\n                   (click)=\"setMinute(i)\"\n                   [class.selected]=\"minute === i\"\n                   [style.backgroundColor]=\"\n                     (minute === i) ?\n                       uiTheme.selectedBackground :\n                       (minuteCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (minute === i) ?\n                       uiTheme.selectedText :\n                       (minuteCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #minuteCol>\n                <span>{{ i | number: '2.0' }}</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div *ngIf=\"timeShowSecond\"\n               class=\"time-col second-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <div class=\"item\"\n                 *ngFor=\"let _ of [].constructor(60); let i = index\">\n              <div class=\"dp-btn\"\n                   (click)=\"setSecond(i)\"\n                   [class.selected]=\"second === i\"\n                   [style.backgroundColor]=\"\n                     (second === i) ?\n                       uiTheme.selectedBackground :\n                       (secondCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (second === i) ?\n                       uiTheme.selectedText :\n                       (secondCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #secondCol>\n                <span>{{ i | number: '2.0' }}</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div *ngIf=\"timeMeridian\"\n               class=\"time-col meridian-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn\"\n                   (click)=\"toggleAmPm('AM')\"\n                   [class.selected]=\"hour < 12\"\n                   [style.backgroundColor]=\"\n                     (hour < 12) ?\n                       uiTheme.selectedBackground :\n                       (amCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (hour < 12) ?\n                       uiTheme.selectedText :\n                       (amCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #amCol>\n                <span>AM</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn\"\n                   (click)=\"toggleAmPm('PM')\"\n                   [class.selected]=\"hour >= 12\"\n                   [style.backgroundColor]=\"\n                     (hour >= 12) ?\n                       uiTheme.selectedBackground :\n                       (pmCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (hour >= 12) ?\n                       uiTheme.selectedText :\n                       (pmCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #pmCol>\n                <span>PM</span>\n              </div>\n            </div>\n          </div>\n        </div>\n      </ng-container>\n      <!-- End: time picker -->\n\n      <!-- Start: toolbox -->\n      <div class=\"the-toolbox horizontal-padding\">\n        <ng-container *ngIf=\"uiTodayBtnEnable\">\n          <div class=\"the-item dp-btn\"\n               [style.backgroundColor]=\"today.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n               [style.color]=\"today.classList.contains('hover') ? uiTheme.hoverText : null\"\n               (click)=\"selectToday()\" themeHover #today>\n            <span>\u0627\u0645\u0631\u0648\u0632</span>\n          </div>\n        </ng-container>\n      </div>\n      <!-- End: toolbox -->\n\n    </div>\n  </div>\n</div>\n", styles: [".datepicker-outer-container{direction:rtl;vertical-align:top;min-width:200px;font-size:12px;padding-top:8px;padding-bottom:8px;-webkit-user-select:none;user-select:none;text-align:center;border-radius:5px;border-width:1px;border-style:solid}.datepicker-outer-container.hide{display:none}.datepicker-outer-container.manual-position{width:100%}.datepicker-outer-container .datepicker-inner-container .horizontal-padding{padding-right:5px;padding-left:5px}.datepicker-outer-container .datepicker-inner-container .no-margin-bottom{margin-bottom:0!important}.datepicker-outer-container .datepicker-inner-container .dp-btn{border-radius:5px}.datepicker-outer-container .datepicker-inner-container .content-container{margin-bottom:8px}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward,.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back{display:inline-block;vertical-align:top;height:24px;cursor:pointer}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back{width:15%;position:relative}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward svg,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back svg{width:12px;height:12px;position:absolute;top:calc(50% - 6px);right:calc(50% - 6px)}.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view{width:66%;margin:0 2%;font-weight:700}.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view span{vertical-align:sub}.datepicker-outer-container .datepicker-inner-container .days-container .day-col{display:inline-block;vertical-align:top;width:14.2857142857%;padding:1px}.datepicker-outer-container .datepicker-inner-container .days-container .day-col .dp-btn{display:flex;flex-direction:column;justify-content:center;align-items:center;min-height:24px}.datepicker-outer-container .datepicker-inner-container .days-container .week-days .day-col{font-weight:700}.datepicker-outer-container .datepicker-inner-container .days-container .month-days .day-col{cursor:pointer}.datepicker-outer-container .datepicker-inner-container .three-col-per-row{display:inline-block;vertical-align:top;width:33.3333333333%;padding:1px;cursor:pointer}.datepicker-outer-container .datepicker-inner-container .three-col-per-row .dp-btn{display:flex;flex-direction:column;justify-content:center;align-content:center;min-height:36px}.datepicker-outer-container .datepicker-inner-container .time-container{border-top-width:1px;border-top-style:solid;border-bottom-width:1px;border-bottom-style:solid;height:82px;direction:ltr;display:flex;flex-direction:row;justify-content:center;align-content:center}.datepicker-outer-container .datepicker-inner-container .time-container .time-col{flex:1;height:100%;overflow:auto}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item{padding:1px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item:first-of-type{padding-top:3px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item:last-of-type{padding-bottom:3px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item .dp-btn{min-height:24px;display:flex;flex-direction:column;justify-content:center;align-content:center}.datepicker-outer-container .datepicker-inner-container .time-container .time-col.meridian-col{display:flex;flex-direction:column;justify-content:center}.datepicker-outer-container .datepicker-inner-container .the-toolbox{text-align:right}.datepicker-outer-container .datepicker-inner-container .the-toolbox .the-item{display:inline-block;vertical-align:top;min-width:40px;cursor:pointer;font-weight:700;padding:3px 5px;margin-left:5px;text-align:center}.datepicker-outer-container .datepicker-inner-container .the-toolbox .the-item:last-child{margin-left:0}\n"], directives: [{ type: ThemeHoverDirective, selector: "[themeHover]" }, { type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], pipes: { "month": MonthPipe, "number": i2.DecimalPipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-persian-datepicker', template: "<div class=\"datepicker-content\">\n  <ng-content></ng-content>\n  <div class=\"datepicker-outer-container\"\n       [style.backgroundColor]=\"uiTheme.background\"\n       [style.color]=\"uiTheme.text\"\n       [style.borderColor]=\"uiTheme.border\"\n       [class.hide]=\"!uiIsVisible\">\n    <div class=\"datepicker-inner-container\">\n\n      <!-- Start: navigation -->\n      <div class=\"content-container navigation-container horizontal-padding\">\n        <div class=\"go-back dp-btn\"\n             [style.backgroundColor]=\"goBack.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             (click)=\"navigate(false)\" themeHover #goBack>\n          <svg xmlns=\"http://www.w3.org/2000/svg\"\n               viewBox=\"0 0 240.823 240.823\"\n               [style.fill]=\"goBack.classList.contains('hover') ? uiTheme.hoverText : uiTheme.text\">\n            <path d=\"M183.189,111.816L74.892,3.555c-4.752-4.74-12.451-4.74-17.215,0c-4.752,4.74-4.752,12.439,0,17.179\n                   l99.707,99.671l-99.695,99.671c-4.752,4.74-4.752,12.439,0,17.191c4.752,4.74,12.463,4.74,17.215,0l108.297-108.261\n                   C187.881,124.315,187.881,116.495,183.189,111.816z\"></path>\n          </svg>\n        </div>\n        <div class=\"switch-view dp-btn\"\n             [style.backgroundColor]=\"switchView.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             [style.color]=\"switchView.classList.contains('hover') ? uiTheme.hoverText : null\"\n             (click)=\"nextViewMode()\" themeHover #switchView>\n          <span>{{ viewDateTitle }}</span>\n        </div>\n        <div class=\"go-forward dp-btn\"\n             [style.backgroundColor]=\"goForward.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n             (click)=\"navigate(true)\" themeHover #goForward>\n          <svg xmlns=\"http://www.w3.org/2000/svg\"\n               viewBox=\"0 0 240.823 240.823\"\n               [style.fill]=\"goForward.classList.contains('hover') ? uiTheme.hoverText : uiTheme.text\">\n            <path d=\"M57.633,129.007L165.93,237.268c4.752,4.74,12.451,4.74,17.215,0c4.752-4.74,4.752-12.439,0-17.179\n                   l-99.707-99.671l99.695-99.671c4.752-4.74,4.752-12.439,0-17.191c-4.752-4.74-12.463-4.74-17.215,0L57.621,111.816\n                   C52.942,116.507,52.942,124.327,57.633,129.007z\"></path>\n          </svg>\n        </div>\n      </div>\n      <!-- End: navigation -->\n\n      <!-- Start: year view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'year'\"\n           class=\"years-container horizontal-padding\">\n        <div class=\"content-container\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <div class=\"year-col three-col-per-row\"\n               (click)=\"yearClick(year)\"\n               *ngFor=\"let year of years\">\n            <div class=\"dp-btn\"\n                 [class.disabled]=\"year.isYearDisabled\"\n                 [class.selected]=\"year.isYearOfSelectedDate\"\n                 [class.today]=\"year.isYearOfTodayDate\"\n                 [style.backgroundColor]=\"\n                   (year.isYearDisabled) ?\n                     uiTheme.disabledBackground :\n                     (year.isYearOfSelectedDate) ?\n                       uiTheme.selectedBackground :\n                       (yearCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         (year.isYearOfTodayDate) ?\n                           uiTheme.todayBackground :\n                           null\n                 \"\n                 [style.color]=\"\n                   (year.isYearDisabled) ?\n                     uiTheme.disabledText :\n                     (year.isYearOfSelectedDate) ?\n                       uiTheme.selectedText :\n                       (yearCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         (year.isYearOfTodayDate) ?\n                           uiTheme.todayText :\n                           null\n                 \"\n                 themeHover #yearCol>\n              <span>{{ year.value }}</span>\n            </div>\n          </div>\n        </div>\n      </div>\n      <!-- End: year view mode -->\n\n      <!-- Start: month view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'month'\"\n           class=\"months-container horizontal-padding\">\n        <div class=\"content-container\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <div class=\"month-col three-col-per-row\"\n               (click)=\"monthClick(month)\"\n               *ngFor=\"let month of months\">\n            <div class=\"dp-btn\"\n                 [class.disabled]=\"month.isMonthDisabled\"\n                 [class.selected]=\"month.isMonthOfSelectedDate\"\n                 [class.today]=\"month.isMonthOfTodayDate\"\n                 [style.backgroundColor]=\"\n                   (month.isMonthDisabled) ?\n                     uiTheme.disabledBackground :\n                     (month.isMonthOfSelectedDate) ?\n                       uiTheme.selectedBackground :\n                       (monthCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         (month.isMonthOfTodayDate) ?\n                           uiTheme.todayBackground :\n                           null\n                 \"\n                 [style.color]=\"\n                   (month.isMonthDisabled) ?\n                     uiTheme.disabledText :\n                     (month.isMonthOfSelectedDate) ?\n                       uiTheme.selectedText :\n                       (monthCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         (month.isMonthOfTodayDate) ?\n                           uiTheme.todayText :\n                           null\n                 \"\n                 themeHover #monthCol>\n              <span>{{ month.indexValue | month }}</span>\n            </div>\n          </div>\n        </div>\n      </div>\n      <!-- End: month view mode -->\n\n      <!-- Start: day view mode -->\n      <div *ngIf=\"viewModes[viewModeIndex] === 'day'\"\n           class=\"days-container horizontal-padding\">\n        <div class=\"content-container week-days\">\n          <div class=\"day-col\"\n               *ngFor=\"let weekDay of weekDays\">\n            <span>{{ weekDay }}</span>\n          </div>\n        </div>\n        <div class=\"content-container month-days\"\n             [class.no-margin-bottom]=\"!timeEnable && !uiTodayBtnEnable\">\n          <ng-container *ngFor=\"let row of days\">\n            <div class=\"day-col\"\n                 (click)=\"dayClick(day)\"\n                 *ngFor=\"let day of row\">\n              <div class=\"dp-btn\"\n                   [class.disabled]=\"day.isDayDisabled\"\n                   [class.selected]=\"day.isDayOfSelectedDate\"\n                   [class.today]=\"day.isDayOfTodayDate\"\n                   [class.other-month]=\"!day.isDayInCurrentMonth\"\n                   [style.backgroundColor]=\"\n                     (day.isDayDisabled) ?\n                       uiTheme.disabledBackground :\n                       (day.isDayOfSelectedDate) ?\n                         uiTheme.selectedBackground :\n                         (dayCol.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           (day.isDayOfTodayDate) ?\n                             uiTheme.todayBackground :\n                             (!day.isDayInCurrentMonth) ?\n                               uiTheme.otherMonthBackground :\n                               null\n                   \"\n                   [style.color]=\"\n                     (day.isDayDisabled) ?\n                       uiTheme.disabledText :\n                       (day.isDayOfSelectedDate) ?\n                         uiTheme.selectedText :\n                         (dayCol.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           (day.isDayOfTodayDate) ?\n                             uiTheme.todayText :\n                             (!day.isDayInCurrentMonth) ?\n                               uiTheme.otherMonthText :\n                               null\n                   \"\n                   themeHover #dayCol>\n                <span>{{ day.value }}</span>\n              </div>\n            </div>\n          </ng-container>\n        </div>\n      </div>\n      <!-- End: day view mode -->\n\n      <!-- Start: time picker -->\n      <ng-container *ngIf=\"timeEnable\">\n        <div class=\"time-container horizontal-padding content-container\"\n             [style.borderTopColor]=\"uiTheme.timeBorder\"\n             [style.borderBottomColor]=\"uiTheme.timeBorder\">\n          <div class=\"time-col hour-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <ng-container *ngIf=\"!timeMeridian\">\n              <div class=\"item\"\n                   *ngFor=\"let _ of [].constructor(24); let i = index\">\n                <div class=\"dp-btn\"\n                     (click)=\"setHour(i)\"\n                     [class.selected]=\"hour === i\"\n                     [style.backgroundColor]=\"\n                       (hour === i) ?\n                         uiTheme.selectedBackground :\n                         (hourCol.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           null\n                     \"\n                     [style.color]=\"\n                       (hour === i) ?\n                         uiTheme.selectedText :\n                         (hourCol.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           null\n                     \" themeHover #hourCol>\n                  <span>{{ i | number: '2.0' }}</span>\n                </div>\n              </div>\n            </ng-container>\n            <ng-container *ngIf=\"timeMeridian\">\n              <div class=\"item\"\n                   *ngFor=\"let _ of [].constructor(12); let i = index\">\n                <div class=\"dp-btn\"\n                     (click)=\"set12Hour(i + 1)\"\n                     [class.selected]=\"\n                       (hour === 0 && (i + 1) === 12) ||\n                       (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                       (hour > 12 && hour === ((i + 1) + 12))\n                     \"\n                     [style.backgroundColor]=\"\n                       (\n                         (hour === 0 && (i + 1) === 12) ||\n                         (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                         (hour > 12 && hour === ((i + 1) + 12))\n                       ) ?\n                         uiTheme.selectedBackground :\n                         (hour12Col.classList.contains('hover')) ?\n                           uiTheme.hoverBackground :\n                           null\n                     \"\n                     [style.color]=\"\n                       (\n                         (hour === 0 && (i + 1) === 12) ||\n                         (hour >= 1 && hour <= 12 && hour === (i + 1)) ||\n                         (hour > 12 && hour === ((i + 1) + 12))\n                       ) ?\n                         uiTheme.selectedText :\n                         (hour12Col.classList.contains('hover')) ?\n                           uiTheme.hoverText :\n                           null\n                     \" themeHover #hour12Col>\n                  <span>{{ (i + 1) | number: '2.0' }}</span>\n                </div>\n              </div>\n            </ng-container>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div class=\"time-col minute-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <div class=\"item\"\n                 *ngFor=\"let _ of [].constructor(60); let i = index\">\n              <div class=\"dp-btn\"\n                   (click)=\"setMinute(i)\"\n                   [class.selected]=\"minute === i\"\n                   [style.backgroundColor]=\"\n                     (minute === i) ?\n                       uiTheme.selectedBackground :\n                       (minuteCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (minute === i) ?\n                       uiTheme.selectedText :\n                       (minuteCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #minuteCol>\n                <span>{{ i | number: '2.0' }}</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div *ngIf=\"timeShowSecond\"\n               class=\"time-col second-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n            <div class=\"item\"\n                 *ngFor=\"let _ of [].constructor(60); let i = index\">\n              <div class=\"dp-btn\"\n                   (click)=\"setSecond(i)\"\n                   [class.selected]=\"second === i\"\n                   [style.backgroundColor]=\"\n                     (second === i) ?\n                       uiTheme.selectedBackground :\n                       (secondCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (second === i) ?\n                       uiTheme.selectedText :\n                       (secondCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #secondCol>\n                <span>{{ i | number: '2.0' }}</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn disabled\"\n                   [style.backgroundColor]=\"uiTheme.disabledBackground\"\n                   [style.color]=\"uiTheme.disabledText\">\n                <span>--</span>\n              </div>\n            </div>\n          </div>\n          <div *ngIf=\"timeMeridian\"\n               class=\"time-col meridian-col\">\n            <div class=\"item\">\n              <div class=\"dp-btn\"\n                   (click)=\"toggleAmPm('AM')\"\n                   [class.selected]=\"hour < 12\"\n                   [style.backgroundColor]=\"\n                     (hour < 12) ?\n                       uiTheme.selectedBackground :\n                       (amCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (hour < 12) ?\n                       uiTheme.selectedText :\n                       (amCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #amCol>\n                <span>AM</span>\n              </div>\n            </div>\n            <div class=\"item\">\n              <div class=\"dp-btn\"\n                   (click)=\"toggleAmPm('PM')\"\n                   [class.selected]=\"hour >= 12\"\n                   [style.backgroundColor]=\"\n                     (hour >= 12) ?\n                       uiTheme.selectedBackground :\n                       (pmCol.classList.contains('hover')) ?\n                         uiTheme.hoverBackground :\n                         null\n                   \"\n                   [style.color]=\"\n                     (hour >= 12) ?\n                       uiTheme.selectedText :\n                       (pmCol.classList.contains('hover')) ?\n                         uiTheme.hoverText :\n                         null\n                   \" themeHover #pmCol>\n                <span>PM</span>\n              </div>\n            </div>\n          </div>\n        </div>\n      </ng-container>\n      <!-- End: time picker -->\n\n      <!-- Start: toolbox -->\n      <div class=\"the-toolbox horizontal-padding\">\n        <ng-container *ngIf=\"uiTodayBtnEnable\">\n          <div class=\"the-item dp-btn\"\n               [style.backgroundColor]=\"today.classList.contains('hover') ? uiTheme.hoverBackground : null\"\n               [style.color]=\"today.classList.contains('hover') ? uiTheme.hoverText : null\"\n               (click)=\"selectToday()\" themeHover #today>\n            <span>\u0627\u0645\u0631\u0648\u0632</span>\n          </div>\n        </ng-container>\n      </div>\n      <!-- End: toolbox -->\n\n    </div>\n  </div>\n</div>\n", styles: [".datepicker-outer-container{direction:rtl;vertical-align:top;min-width:200px;font-size:12px;padding-top:8px;padding-bottom:8px;-webkit-user-select:none;user-select:none;text-align:center;border-radius:5px;border-width:1px;border-style:solid}.datepicker-outer-container.hide{display:none}.datepicker-outer-container.manual-position{width:100%}.datepicker-outer-container .datepicker-inner-container .horizontal-padding{padding-right:5px;padding-left:5px}.datepicker-outer-container .datepicker-inner-container .no-margin-bottom{margin-bottom:0!important}.datepicker-outer-container .datepicker-inner-container .dp-btn{border-radius:5px}.datepicker-outer-container .datepicker-inner-container .content-container{margin-bottom:8px}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward,.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back{display:inline-block;vertical-align:top;height:24px;cursor:pointer}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back{width:15%;position:relative}.datepicker-outer-container .datepicker-inner-container .navigation-container .go-forward svg,.datepicker-outer-container .datepicker-inner-container .navigation-container .go-back svg{width:12px;height:12px;position:absolute;top:calc(50% - 6px);right:calc(50% - 6px)}.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view{width:66%;margin:0 2%;font-weight:700}.datepicker-outer-container .datepicker-inner-container .navigation-container .switch-view span{vertical-align:sub}.datepicker-outer-container .datepicker-inner-container .days-container .day-col{display:inline-block;vertical-align:top;width:14.2857142857%;padding:1px}.datepicker-outer-container .datepicker-inner-container .days-container .day-col .dp-btn{display:flex;flex-direction:column;justify-content:center;align-items:center;min-height:24px}.datepicker-outer-container .datepicker-inner-container .days-container .week-days .day-col{font-weight:700}.datepicker-outer-container .datepicker-inner-container .days-container .month-days .day-col{cursor:pointer}.datepicker-outer-container .datepicker-inner-container .three-col-per-row{display:inline-block;vertical-align:top;width:33.3333333333%;padding:1px;cursor:pointer}.datepicker-outer-container .datepicker-inner-container .three-col-per-row .dp-btn{display:flex;flex-direction:column;justify-content:center;align-content:center;min-height:36px}.datepicker-outer-container .datepicker-inner-container .time-container{border-top-width:1px;border-top-style:solid;border-bottom-width:1px;border-bottom-style:solid;height:82px;direction:ltr;display:flex;flex-direction:row;justify-content:center;align-content:center}.datepicker-outer-container .datepicker-inner-container .time-container .time-col{flex:1;height:100%;overflow:auto}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item{padding:1px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item:first-of-type{padding-top:3px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item:last-of-type{padding-bottom:3px}.datepicker-outer-container .datepicker-inner-container .time-container .time-col .item .dp-btn{min-height:24px;display:flex;flex-direction:column;justify-content:center;align-content:center}.datepicker-outer-container .datepicker-inner-container .time-container .time-col.meridian-col{display:flex;flex-direction:column;justify-content:center}.datepicker-outer-container .datepicker-inner-container .the-toolbox{text-align:right}.datepicker-outer-container .datepicker-inner-container .the-toolbox .the-item{display:inline-block;vertical-align:top;min-width:40px;cursor:pointer;font-weight:700;padding:3px 5px;margin-left:5px;text-align:center}.datepicker-outer-container .datepicker-inner-container .the-toolbox .the-item:last-child{margin-left:0}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { _formControlDirective: [{
                type: ContentChild,
                args: [FormControlDirective, { static: false }]
            }], _formControlName: [{
                type: ContentChild,
                args: [FormControlName, { static: false }]
            }], inputDateValue: [{
                type: Input,
                args: ['dateValue']
            }], dateInitValue: [{
                type: Input
            }], dateIsGregorian: [{
                type: Input
            }], _dateFormat: [{
                type: Input,
                args: ['dateFormat']
            }], dateGregorianFormat: [{
                type: Input
            }], _dateMin: [{
                type: Input,
                args: ['dateMin']
            }], _dateMax: [{
                type: Input,
                args: ['dateMax']
            }], _timeEnable: [{
                type: Input,
                args: ['timeEnable']
            }], _timeShowSecond: [{
                type: Input,
                args: ['timeShowSecond']
            }], _timeMeridian: [{
                type: Input,
                args: ['timeMeridian']
            }], _uiTheme: [{
                type: Input,
                args: ['uiTheme']
            }], uiIsVisible: [{
                type: Input
            }], uiHideOnOutsideClick: [{
                type: Input
            }], uiHideAfterSelectDate: [{
                type: Input
            }], _uiYearView: [{
                type: Input,
                args: ['uiYearView']
            }], _uiMonthView: [{
                type: Input,
                args: ['uiMonthView']
            }], uiInitViewMode: [{
                type: Input
            }], uiTodayBtnEnable: [{
                type: Input
            }], dateOnInit: [{
                type: Output
            }], dateOnSelect: [{
                type: Output
            }], uiIsVisibleChange: [{
                type: Output
            }], onInsideClick: [{
                type: HostListener,
                args: ['click']
            }], onOutsideClick: [{
                type: HostListener,
                args: ['document:click']
            }] } });

class NgPersianDatepickerModule {
}
NgPersianDatepickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgPersianDatepickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerModule, declarations: [NgPersianDatepickerComponent,
        ThemeHoverDirective,
        MonthPipe], imports: [CommonModule], exports: [NgPersianDatepickerComponent] });
NgPersianDatepickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerModule, imports: [[
            CommonModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.8", ngImport: i0, type: NgPersianDatepickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgPersianDatepickerComponent,
                        ThemeHoverDirective,
                        MonthPipe,
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        NgPersianDatepickerComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ng-persian-datepicker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgPersianDatepickerComponent, NgPersianDatepickerModule, defaultTheme };
//# sourceMappingURL=ng-persian-datepicker.mjs.map
